﻿(***********************************************************)
(***********************************************************)
(*  Copyright (c) 2014 Janus Technology Limited            *)
(*                                                         *)
(*  TVONE_C2 Video Switcher driver build main project file *)
(***********************************************************)
program_name='tvONE_C2_Video_Switcher_Build'

(***********************************************************)
(*          DEVICE NUMBER DEFINITIONS GO BELOW             *)
(***********************************************************)
define_device

dvTP   = 10001:1:1
dvTVONE_C2   = 0:4:0      // TCP
vdvTVONE_C2  = 33001:1:1

AB_DEBUG = 33399:1:0
(***********************************************************)
(*               CONSTANT DEFINITIONS GO BELOW             *)
(***********************************************************)
define_constant

CMD_DEVICE_SOURCE_HDMI   = 50
CMD_DEVICE_SOURCE_DVI_U  = 51
CMD_DEVICE_SOURCE_PC_HD  = 52
CMD_DEVICE_SOURCE_CV     = 53
CMD_DEVICE_SOURCE_YC     = 54
CMD_DEVICE_SOURCE_SDI    = 55
CMD_DEVICE_SOURCE_SIS1   = 56
CMD_DEVICE_SOURCE_SIS2   = 57
CMD_DEVICE_SOURCE_SIS3   = 58
CMD_DEVICE_SOURCE_SIS4   = 59
CMD_DEVICE_SOURCE_SIS5   = 60
CMD_DEVICE_PRESET_1      = 61
CMD_DEVICE_PRESET_2      = 62
CMD_DEVICE_PRESET_3      = 63
CMD_DEVICE_PRESET_4      = 64
CMD_DEVICE_PRESET_5      = 65
CMD_DEVICE_PRESET_6      = 66
CMD_DEVICE_PRESET_7      = 67
CMD_DEVICE_PRESET_8      = 68
CMD_DEVICE_PRESET_9      = 69
CMD_DEVICE_PRESET_10     = 70
CMD_DEVICE_PRESET_11     = 71
CMD_DEVICE_PRESET_12     = 72
CMD_DEVICE_RESET         = 73

TP_VERSION = 118
TP_STATUS = 119

(***********************************************************)
(*               VARIABLE DEFINITIONS GO BELOW             *)
(***********************************************************)
define_variable
// Ensure that this version number gets updated for each new
// version of the module in the tvONE_C2_Video_Switcher include file

// TCP/IP parameters for the C2-2885 device 
char TVONE_SWITCH_IP[15] = '172.16.105.2';  
long TVONE_SWITCH_IP_PORT = 10001;

// List of C2 commands buttons displayed
integer SOURCE_BUTTONS[] = 
{
  CMD_DEVICE_SOURCE_HDMI, CMD_DEVICE_SOURCE_DVI_U, CMD_DEVICE_SOURCE_PC_HD, 
  CMD_DEVICE_SOURCE_CV, CMD_DEVICE_SOURCE_YC, CMD_DEVICE_SOURCE_SDI,
  CMD_DEVICE_SOURCE_SIS1, CMD_DEVICE_SOURCE_SIS2, CMD_DEVICE_SOURCE_SIS3,
  CMD_DEVICE_SOURCE_SIS4, CMD_DEVICE_SOURCE_SIS5
};

char SOURCE_CMDS[11][15] =
{
  'SOURCE_HDMI','SOURCE_DVI_U','SOURCE_PC_HD','SOURCE_CV', 'SOURCE_YC', 'SOURCE_SDI', 'SOURCE_SIS1',
  'SOURCE_SIS2','SOURCE_SIS3', 'SOURCE_SIS4','SOURCE_SIS5'
};

integer PRESET_BUTTONS[] = 
{
  CMD_DEVICE_PRESET_1, CMD_DEVICE_PRESET_2, CMD_DEVICE_PRESET_3, CMD_DEVICE_PRESET_4,
  CMD_DEVICE_PRESET_5, CMD_DEVICE_PRESET_6, CMD_DEVICE_PRESET_7, CMD_DEVICE_PRESET_8,
  CMD_DEVICE_PRESET_9, CMD_DEVICE_PRESET_10, CMD_DEVICE_PRESET_11, CMD_DEVICE_PRESET_12
};

char PRESET_CMDS[12][2] =
{
  '1','2','3','4','5','6','7','8','9','10','11','12'
};

(***********************************************************)
(*                FUNCTIONS GO BELOW                       *)
(***********************************************************)


(***********************************************************)
(*                 MODULES GO BELOW                        *)
(***********************************************************)

define_module 'tvONE_C2_Switcher' tvONE_C2_Switcher( vdvTVONE_C2, dvTVONE_C2, TVONE_SWITCH_IP, TVONE_SWITCH_IP_PORT );

(***********************************************************)
(*              STARTUP CODE GOES BELOW                    *)
(***********************************************************)
define_start
{
  
}

(***********************************************************)
(*                THE EVENTS GO BELOW                      *)
(***********************************************************)
define_event

// Handle source command event
button_event [dvTP, SOURCE_BUTTONS]
{
  push:
  {
    integer btn;
    
    btn =  get_last( SOURCE_BUTTONS );
    send_command vdvTVONE_C2, "'SOURCE=',SOURCE_CMDS[btn]";
  }
}

// Handle preset command event
button_event [dvTP, PRESET_BUTTONS]
{
  push:
  {
    integer btn;
    
    btn = get_last( PRESET_BUTTONS );
    send_command vdvTVONE_C2, "'LOADPRESET=',PRESET_CMDS[btn]";
    
  }
}

// Handle reset command event
button_event [dvTP, CMD_DEVICE_RESET]
{
  push:
  {
    send_command vdvTVONE_C2, "'RESET'";
  }
}

// Handle data event to display version
data_event [vdvTVONE_C2]  
{
  string:
  {
    char cmd[16];
    
    cmd = remove_string( data.text, '=', 1 );
    while (length_string( cmd ) > 0)
    {
      switch (cmd)
      {
	case 'VERSION=':
	{
           send_command dvTP, "'^TXT-',itoa( TP_VERSION ),',0,',data.text";
	   BREAK
	}
	
	case 'STATUS=':
	{
           send_command dvTP, "'^TXT-',itoa( TP_STATUS ),',0,',data.text";
	   BREAK
	}
	default:
	{
	  BREAK
	}
      }
      cmd = remove_string( data.text, ' ', 1 );      
    }
  } 
}


